@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
-our $DATE = '2017-07-11'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2018-11-29'; # DATE
+our $VERSION = '0.810'; # VERSION
 
 use 5.010001;
 use strict;
@@ -323,7 +323,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.80 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2017-07-11.
+This document describes version 0.810 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2018-11-29.
 
 =head1 DESCRIPTION
 
@@ -340,7 +340,7 @@ section).
 
 Usage:
 
- demo_cli_opts(%args) -> [status, msg, result, meta]
+ demo_cli_opts(%args) -> [status, msg, payload, meta]
 
 Summary for `demo_cli_opts`.
 
@@ -354,45 +354,19 @@ Examples:
 
 Result:
 
- [
-   200,
-   "OK",
-   {
-     array1 => ["elem1", "elem2"],
-     full   => 1,
-     full2  => 1,
-     hash1  => { default => 1 },
-     int1   => 10,
-     int2   => 10,
-     str1   => "a value",
-   },
-   {},
- ]
+ {
+   array1 => ["elem1", "elem2"],
+   full   => 1,
+   full2  => 1,
+   hash1  => { default => 1 },
+   int1   => 10,
+   int2   => 10,
+   str1   => "a value",
+ }
 
 =item * A second example:
 
- demo_cli_opts( str1 => "x", array1 => [1, 2], int1 => 20);
-
-Result:
-
- [
-   400,
-   "Can't parse argv",
-   undef,
-   {
-     logs => [
-               {
-                 file    => "/home/s1/perl5/perlbrew/perls/perl-5.26.0/lib/site_perl/5.26.0/Perinci/Access/Schemeless.pm",
-                 func    => "Perinci::Access::Schemeless::action_call",
-                 line    => 494,
-                 package => "Perinci::Access::Schemeless",
-                 time    => 1499762835,
-                 type    => "create",
-               },
-             ],
-     prev => [500, "GetOptions failed"],
-   },
- ]
+ demo_cli_opts( str1 => "x", array1 => [1, 2], int1 => 20); # -> undef
 
 =back
 
@@ -527,7 +501,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -538,7 +512,7 @@ Return value:  (any)
 
 Usage:
 
- demo_cli_opts_shorter(%args) -> [status, msg, result, meta]
+ demo_cli_opts_shorter(%args) -> [status, msg, payload, meta]
 
 Function summary.
 
@@ -548,11 +522,7 @@ Examples:
 
 =item * Summary for an example:
 
- demo_cli_opts_shorter( str1 => "a value", bool1 => 1);
-
-Result:
-
- [200, "OK", { bool1 => 1, str1 => "a value" }, {}]
+ demo_cli_opts_shorter( str1 => "a value", bool1 => 1); # -> { bool1 => 1, str1 => "a value" }
 
 =back
 
@@ -579,7 +549,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -613,7 +583,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
