@@ -1,7 +1,7 @@
 package Perinci::Examples::CSV;
 
-our $DATE = '2017-07-11'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2018-11-29'; # DATE
+our $VERSION = '0.810'; # VERSION
 
 use 5.010;
 use strict;
@@ -43,7 +43,7 @@ Perinci::Examples::CSV - Test CSV output
 
 =head1 VERSION
 
-This document describes version 0.80 of Perinci::Examples::CSV (from Perl distribution Perinci-Examples), released on 2017-07-11.
+This document describes version 0.810 of Perinci::Examples::CSV (from Perl distribution Perinci-Examples), released on 2018-11-29.
 
 =head1 DESCRIPTION
 
@@ -54,7 +54,7 @@ This document describes version 0.80 of Perinci::Examples::CSV (from Perl distri
 
 Usage:
 
- output_table() -> [status, msg, result, meta]
+ output_table() -> [status, msg, payload, meta]
 
 Output some table, try displaying it on CLI with --format=csv.
 
@@ -67,7 +67,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -95,7 +95,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
