@@ -1,7 +1,7 @@
 package Perinci::Examples::CmdLineResMeta;
 
-our $DATE = '2017-07-11'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2018-11-29'; # DATE
+our $VERSION = '0.810'; # VERSION
 
 use 5.010;
 use strict;
@@ -88,7 +88,7 @@ Perinci::Examples::CmdLineResMeta - Functions in this package contains cmdline.*
 
 =head1 VERSION
 
-This document describes version 0.80 of Perinci::Examples::CmdLineResMeta (from Perl distribution Perinci-Examples), released on 2017-07-11.
+This document describes version 0.810 of Perinci::Examples::CmdLineResMeta (from Perl distribution Perinci-Examples), released on 2018-11-29.
 
 =head1 FUNCTIONS
 
@@ -97,7 +97,7 @@ This document describes version 0.80 of Perinci::Examples::CmdLineResMeta (from
 
 Usage:
 
- default_format() -> [status, msg, result, meta]
+ default_format() -> [status, msg, payload, meta]
 
 Set cmdline.default_format json.
 
@@ -110,7 +110,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -121,7 +121,7 @@ Return value:  (any)
 
 Usage:
 
- exit_code() -> [status, msg, result, meta]
+ exit_code() -> [status, msg, payload, meta]
 
 Returns cmdline exit code 7, even though status is 200.
 
@@ -134,7 +134,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -145,7 +145,7 @@ Return value:  (any)
 
 Usage:
 
- is_palindrome(%args) -> [status, msg, result, meta]
+ is_palindrome(%args) -> [status, msg, payload, meta]
 
 Return true if string is palindrome.
 
@@ -164,7 +164,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -175,7 +175,7 @@ Return value:  (any)
 
 Usage:
 
- result() -> [status, msg, result, meta]
+ result() -> [status, msg, payload, meta]
 
 Returns false, but cmdline.result the string "false".
 
@@ -188,7 +188,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -199,7 +199,7 @@ Return value:  (any)
 
 Usage:
 
- skip_format() -> [status, msg, result, meta]
+ skip_format() -> [status, msg, payload, meta]
 
 Set cmdline.skip_format => 1.
 
@@ -212,7 +212,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -240,7 +240,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
