@@ -1,7 +1,7 @@
 package Perinci::Examples::ResultNaked;
 
-our $DATE = '2017-07-11'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2018-11-29'; # DATE
+our $VERSION = '0.810'; # VERSION
 
 use 5.010001;
 use strict;
@@ -76,7 +76,7 @@ Perinci::Examples::ResultNaked - Demonstrate `result_naked` property
 
 =head1 VERSION
 
-This document describes version 0.80 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2017-07-11.
+This document describes version 0.810 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2018-11-29.
 
 =head1 DESCRIPTION
 
@@ -108,11 +108,15 @@ Examples:
 
 =item * Without the optional arg3:
 
- result_naked(arg1 => "abc", arg2 => 10); # -> ["arg1", "abc", "arg2", 10]
+ result_naked(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg1", "abc", "arg2", 10]]
 
 =item * With the optional arg3:
 
- result_naked(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg3", 0.5, "arg1", "def", "arg2", 20]
+ result_naked(arg1 => "def", arg2 => 20, arg3 => 0.5);
+
+Result:
+
+ [200, "OK", ["arg2", 20, "arg3", 0.5, "arg1", "def"]]
 
 =back
 
@@ -137,7 +141,7 @@ Return value:  (any)
 
 Usage:
 
- result_not_naked(%args) -> [status, msg, result, meta]
+ result_not_naked(%args) -> [status, msg, payload, meta]
 
 This is the default.
 
@@ -147,15 +151,11 @@ Examples:
 
 =item * Without the optional arg3:
 
- result_not_naked(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg2", 10, "arg1", "abc"], {}]
+ result_not_naked(arg1 => "abc", arg2 => 10); # -> ["arg1", "abc", "arg2", 10]
 
 =item * With the optional arg3:
 
- result_not_naked(arg1 => "def", arg2 => 20, arg3 => 0.5);
-
-Result:
-
- [200, "OK", ["arg3", 0.5, "arg1", "def", "arg2", 20], {}]
+ result_not_naked(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg2", 20, "arg3", 0.5, "arg1", "def"]
 
 =back
 
@@ -178,7 +178,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -206,7 +206,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
