@@ -1,7 +1,7 @@
 package Perinci::Examples::Tiny;
 
-our $DATE = '2017-07-11'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2018-11-29'; # DATE
+our $VERSION = '0.810'; # VERSION
 
 our %SPEC;
 
@@ -173,7 +173,7 @@ Perinci::Examples::Tiny - Small examples
 
 =head1 VERSION
 
-This document describes version 0.80 of Perinci::Examples::Tiny (from Perl distribution Perinci-Examples), released on 2017-07-11.
+This document describes version 0.810 of Perinci::Examples::Tiny (from Perl distribution Perinci-Examples), released on 2018-11-29.
 
 =head1 DESCRIPTION
 
@@ -187,7 +187,7 @@ benchmarking startup overhead of L<Perinci::CmdLine::Inline>-generated scripts.
 
 Usage:
 
- foo1() -> [status, msg, result, meta]
+ foo1() -> [status, msg, payload, meta]
 
 Return the string 'foo1'.
 
@@ -200,7 +200,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -211,7 +211,7 @@ Return value:  (any)
 
 Usage:
 
- foo2() -> [status, msg, result, meta]
+ foo2() -> [status, msg, payload, meta]
 
 Return the string 'foo1'.
 
@@ -224,7 +224,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -235,7 +235,7 @@ Return value:  (any)
 
 Usage:
 
- foo3() -> [status, msg, result, meta]
+ foo3() -> [status, msg, payload, meta]
 
 Return the string 'foo1'.
 
@@ -248,7 +248,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -259,7 +259,7 @@ Return value:  (any)
 
 Usage:
 
- foo4() -> [status, msg, result, meta]
+ foo4() -> [status, msg, payload, meta]
 
 Return the string 'foo1'.
 
@@ -272,7 +272,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -298,7 +298,7 @@ Return value:  (any)
 
 Usage:
 
- noop() -> [status, msg, result, meta]
+ noop() -> [status, msg, payload, meta]
 
 Do nothing.
 
@@ -311,7 +311,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -322,7 +322,7 @@ Return value:  (any)
 
 Usage:
 
- noop2(%args) -> [status, msg, result, meta]
+ noop2(%args) -> [status, msg, payload, meta]
 
 Just like noop, but accepts several arguments.
 
@@ -368,7 +368,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -379,7 +379,7 @@ Return value:  (any)
 
 Usage:
 
- odd_even(%args) -> [status, msg, result, meta]
+ odd_even(%args) -> [status, msg, payload, meta]
 
 Return 'odd' or 'even' depending on the number.
 
@@ -400,7 +400,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -411,7 +411,7 @@ Return value:  (str)
 
 Usage:
 
- sum(%args) -> [status, msg, result, meta]
+ sum(%args) -> [status, msg, payload, meta]
 
 Sum numbers in array.
 
@@ -438,7 +438,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -466,7 +466,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
