@@ -1,7 +1,7 @@
 package Perinci::Examples::Tiny::Result;
 
-our $DATE = '2017-07-11'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2018-11-29'; # DATE
+our $VERSION = '0.810'; # VERSION
 
 our %SPEC;
 
@@ -54,7 +54,7 @@ Perinci::Examples::Tiny::Result - Tests related to function result
 
 =head1 VERSION
 
-This document describes version 0.80 of Perinci::Examples::Tiny::Result (from Perl distribution Perinci-Examples), released on 2017-07-11.
+This document describes version 0.810 of Perinci::Examples::Tiny::Result (from Perl distribution Perinci-Examples), released on 2018-11-29.
 
 =head1 DESCRIPTION
 
@@ -69,7 +69,7 @@ Perinci::CmdLine frameworks.
 
 Usage:
 
- returns_circular() -> [status, msg, result, meta]
+ returns_circular() -> [status, msg, payload, meta]
 
 This function returns circular structure.
 
@@ -84,7 +84,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -95,7 +95,7 @@ Return value:  (any)
 
 Usage:
 
- returns_scalar_ref() -> [status, msg, result, meta]
+ returns_scalar_ref() -> [status, msg, payload, meta]
 
 This function returns a scalar reference.
 
@@ -110,7 +110,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -138,7 +138,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
