@@ -1,7 +1,7 @@
 package Perinci::Examples::Tx;
 
-our $DATE = '2017-07-11'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2018-11-29'; # DATE
+our $VERSION = '0.810'; # VERSION
 
 use 5.010;
 use strict;
@@ -39,7 +39,7 @@ Perinci::Examples::Tx - Examples for using transaction
 
 =head1 VERSION
 
-This document describes version 0.80 of Perinci::Examples::Tx (from Perl distribution Perinci-Examples), released on 2017-07-11.
+This document describes version 0.810 of Perinci::Examples::Tx (from Perl distribution Perinci-Examples), released on 2018-11-29.
 
 =head1 FUNCTIONS
 
@@ -48,7 +48,7 @@ This document describes version 0.80 of Perinci::Examples::Tx (from Perl distrib
 
 Usage:
 
- check_state() -> [status, msg, result, meta]
+ check_state() -> [status, msg, payload, meta]
 
 Return 'check_state' if checking state, otherwise empty string.
 
@@ -90,7 +90,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -118,7 +118,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
